package ppx_type_directed_value

  1. Overview
  2. Docs

Module Type_directed.Indexed_seqSource

A generic data structure that models a list of 'a M.t, where the first index of the GADT is the product of each type used to instantiate 'a M.t in the list, and the second index tracks the length of the list using Type_nat

Sourcemodule Any_length (M : Base.T1) : sig ... end
Sourcemodule Length_at_least_one (M : Base.T1) : sig ... end
Sourcemodule Length_at_least_two (M : Base.T1) : sig ... end